@@ -61,8 +61,8 @@ class CustomPersister:
         if dirname and not os.path.exists(dirname):
             os.makedirs(dirname)
         with open(cassette_path, "wb") as f:
-            f.write(data)
-            #f.write(data.encode('utf-8'))
+            #f.write(data)
+            f.write(data.encode('utf-8'))
 
 
 def filter_cassette(
